## [1.1.0](https://github.com/ocni-dtu/epdx/compare/v1.0.0...v1.1.0) (2024-02-05)


### Features

* added km and tones_km to units ([08f6480](https://github.com/ocni-dtu/epdx/commit/08f6480464a3583db6955d21d9e2b57279c9398c))
* added meta_data to conversion struct ([b4fa5c1](https://github.com/ocni-dtu/epdx/commit/b4fa5c1254691c1263b5048570675d300661bfd7))


### Bug Fixes

* refactored ILCD parsing functions and added more test cases for ILCD files ([35256b6](https://github.com/ocni-dtu/epdx/commit/35256b672c828283c262c5affdcc7f85f10575c1))

## 1.0.0 (2024-01-24)


### Features

* added error handling to ilcd parsing ([bc9beb9](https://github.com/ocni-dtu/epdx/commit/bc9beb9f478fa4f26292f741cfe4fe04e319360d))
* improved support for js and ts ([c938488](https://github.com/ocni-dtu/epdx/commit/c9384887d395adba7a53ca13ce6b14f6332f5130))
* made it optional to whether convert_ilcd should return string, dict or pydantic ([720ca62](https://github.com/ocni-dtu/epdx/commit/720ca6284597c5f79ef600a4abcc16fa311e9976))
